---
title: get_agent_id
description: Return the AgentID of the current agent.
---

## Signature

```py
def get_agent_id() -> AgentID
```

## Description

Returns the unique `AgentID` assigned to the current agent

## Example

```py
agent_id = get_agent_id()
print(agent_id)
# Outputs: [ ID x , GID y ]
```
